# Patchwork node

Worker node for Patchwork - an asynchronous distributed microservices framework.

## Requirements
* Python 3.7

## Installation

``pip install pachwork-node``

## Documentation

https://patchwork-framework.gitlab.io/core